@@ -49,11 +49,16 @@ def entry_point():
     """ Downloads the entrypoint used as command for any container created with this image
         and gives execution permissions to it.
     """
-    commands = [('wget -q -O /entry_point.py https://raw.githubusercontent.com/'
-                 'Vauxoo/docker_entrypoint/master/entry_point.py'),
-                'chmod +x /entry_point.py']
+    commands = [
+        ('wget -q -O-'
+         ' https://raw.githubusercontent.com/Vauxoo/docker_entrypoint/master/installer.sh | sh'),
+        ('wget -q -O /entry_point.py'
+         ' https://raw.githubusercontent.com/Vauxoo/docker_entrypoint/master/entry_point.py'),
+        'chmod +x /entry_point',
+        'chmod +x /entry_point.py'
+    ]
     for command in commands:
-        subprocess.check_call(shlex.split(command))
+        subprocess.check_call(command, shell=True)
 
 
 def search_apt_requirements(folder_name, file_name=None, recursive=False):
